@@ -6,13 +6,15 @@ FrontMatter:
 """
 
 from base64 import b64encode
-from typing import Any, Dict, Optional
+from typing import Any, Dict, TypeVar, Optional
 
 from nonebot.typing import overrides
 from nonebot.utils import DataclassEncoder
 
 from .exception import ActionFailed
 
+T = TypeVar("T")
+
 
 def get_auth_bearer(access_token: Optional[str] = None) -> Optional[str]:
     if not access_token:
@@ -46,6 +48,28 @@ def handle_api_result(result: Optional[Dict[str, Any]]) -> Any:
         return result.get("data")
 
 
+def flattened_to_nested(data: T) -> T:
+    """将扁平键值转为嵌套字典。"""
+    if isinstance(data, dict):
+        pairs = [
+            (
+                key.split(".") if isinstance(key, str) else key,
+                flattened_to_nested(value),
+            )
+            for key, value in data.items()
+        ]
+        result = {}
+        for key_list, value in pairs:
+            target = result
+            for key in key_list[:-1]:
+                target = target.setdefault(key, {})
+            target[key_list[-1]] = value
+        return result  # type: ignore
+    elif isinstance(data, list):
+        return [flattened_to_nested(item) for item in data]  # type: ignore
+    return data
+
+
 class CustomEncoder(DataclassEncoder):
     """OneBot V12 使用的 `JSONEncoder`"""
 
